;; Generated package description from autocrypt.el  -*- no-byte-compile: t -*-
(define-package "autocrypt" "0.4.1.0.20230505.70117" "Autocrypt implementation" '((emacs "24.3")) :commit "e827b91afa5ffc88bc0c6142ff423b5ef93874e3" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "~pkal/public-inbox@lists.sr.ht") :keywords '("comm") :url "https://git.sr.ht/~pkal/autocrypt")
